;; The "Acetylene Data" example of Marquardt and Snee (1975), The American
;; Statistician, 29, 3-20.
;; X1 = ( Temperature - 1212.5 ) / 80.623
;; X2 = ( H2/n-Heptane - 12.44 ) / 5.662
;; X3 = ( Contact Time - .0403 ) / .03164
;; X4 = X1 * X2
;; X5 = X1 * X3
;; X6 = X2 * X3
;; X7 = X1 squared
;; X8 = X1 squared
;; X9 = X3 squared
;; Y  = ( % Conversion to Acetylene - 36.106 ) / 11.899
;;
;; Fetch softRX shrinkage routines if they haven't already been loaded.
;;

(require "RXridge")

;;
;; Load data columnwise from ASCII format file into the variable acetylen-dat.
;;

(def acetylen-dat (read-data-columns "acetylen.dat" 10))

;;
;; Save regressor/response coordinates in individual variable names.
;;

(def temp    (select acetylen-dat 0))               ; get single variables
(def h2hp    (select acetylen-dat 1))               ; out of read data
(def ctim    (select acetylen-dat 2))
(def t*h     (select acetylen-dat 3))
(def t*c     (select acetylen-dat 4))
(def h*c     (select acetylen-dat 5))
(def t^2     (select acetylen-dat 6))
(def h^2     (select acetylen-dat 7))
(def c^2     (select acetylen-dat 8))
(def conv    (select acetylen-dat 9))

;;
;; Then construct a XLisp-Stat regression object...
;;

(def acetylen-reg (regression-model
 (list temp h2hp ctim t*h t*c h*c t^2 h^2 c^2) conv
 :predictor-names '("TEMP" "H2HP" "CTIM" "T*H" "T*C" "H*C" "T^2" "H^2" "C^2" )
 :response-name "CONV"
                  )
)

;;
;; Inform user of the NAME of the model object ...so that he/she can send
;; his/her own messages to the object!!!
;;

(format t "(RXridge regression model is called 'acetylen-reg') ~%")

;;
;; Create a MENU for the model.
;;

(send acetylen-reg :RXridge-menu "Acetylene")
(send acetylen-reg :RXridge-compute-summary)

;;
;; Everything else can be done interactively with the "Acetylene" MENU!!!
;;
