;; The "Air Polution & Mortality" data of McDonald and Schwing (1973).
;; Technometrics 15, 463-481...weather, socioeconomic, and pollution
;; data for 60 SMSAs (1960.)
;;
;;     PRECIP = mean annual precipitation in inches.
;;     JANTMP = mean January Fahrenheight temperature
;;     JULTMP = mean July Fahrenheight temperature
;;     OVR65% = percent of population 65 years or older
;;     POPHOS = population per household
;;     SCHYRS = median school years completed by population over 25 years
;;     SOUND% = percent of housing units sound with all facilities
;;     DENSIT = population per square mile in urban area
;;     NONWT% = percent of non-white population in urban area
;;     WTCOL% = percent employment in white-collar occupations
;;     UND3K% = percent of family incomes less tha 3,000
;;     HC     = relative pollution potential of hydrocarbons
;;     NOX    = relative pollution potential of oxides of nitrogen
;;     SO2    = relative pollution potential of sulfur dioxide
;;     RELHM% = percent relative humidity, annual average at 1PM
;;     MORTAL = total age adjusted mortality rate from all causes
;;
;; Fetch softRX shrinkage routines if they haven't already been loaded.
;;

(require "RXridge")

;;
;; Load data columnwise from ASCII format file into the variable airpolut-dat.
;;

(def airpolut-dat (read-data-columns "airpolut.dat" 16))

;;
;; Save regressor/response coordinates in individual variable names.
;;

(def precip  (select airpolut-dat  0))               ; get single variables
(def jantmp  (select airpolut-dat  1))               ; out of read data
(def jultmp  (select airpolut-dat  2))
(def ovr65%  (select airpolut-dat  3))
(def pophos  (select airpolut-dat  4))
(def schyrs  (select airpolut-dat  5))
(def sound%  (select airpolut-dat  6))
(def densit  (select airpolut-dat  7))
(def nonwt%  (select airpolut-dat  8))
(def wtcol%  (select airpolut-dat  9))
(def und3k%  (select airpolut-dat 10))
(def hc      (select airpolut-dat 11))
(def nox     (select airpolut-dat 12))
(def so2     (select airpolut-dat 13))
(def relhm%  (select airpolut-dat 14))
(def mortal  (select airpolut-dat 15))

;;
;; Then construct a XLisp-Stat regression object...
;;

(def airpolut-reg (regression-model
              (list precip jantmp jultmp ovr65% pophos schyrs sound% densit
               nonwt% wtcol% und3k% hc nox so2 relhm%) mortal
 :predictor-names '("PRECIP" "JANTMP" "JULTMP" "OVR65%" "POPHOS" "SCHYRS"
                    "SOUND%" "DENSIT" "NONWT%" "WTCOL%" "UND3K%" "HC"
                    "NOX" "SO2" "RELHM%")
 :response-name "MORTAL"
                  )
)

;;
;; Inform user of the NAME of the model object ...so that he/she can send
;; his/her own messages to the object!!!
;;

(format t "(RXridge regression model is called 'airpolut-reg') ~%")

;;
;; Create a MENU for the model.
;;

(send airpolut-reg :RXridge-menu "AirPolution")
(send airpolut-reg :RXridge-compute-summary)

;;
;; Everything else can be done interactively with the "AirPolution" MENU!!!
;;

