;;  The U.S. coal mining fatalities data of Lawrence and Marsh(1984),
;;  Comm. Statist. - Theor. Meth. 13, 139-149. ...a Cobb-Douglas
;;  production function, treating work-related fatalities as a form of
;;  "perverse production."  Because these data contain some highly
;;  "influential" observations (leveraged regressors and "mine disaster"
;;  jumps) .001 was added (instead of .0001) to variables containing zero
;;  values before taking their logarithms.
;;
;;    CUTTERS  = Log of Number of Cutting machines in use.
;;    TONPERHR = Log of Coal Output (ShortTons/LaborHour).
;;    UNDRGRND = Log of Avg.Number of Underground Miners.
;;    MOBILES  = Log of .001 + Number of Mobile Loaders in use.
;;    CONTINS  = Log of .001 + Number of Continuous Machines.
;;    TOTPROHR = Log of Tot.Labor Hours of Production Work.
;;
;;    FATALS = Log of .001 + Number of Fatalities from gas and
;;                           dust explosions, 1915-1978.
;;
;; Fetch softRX shrinkage routines if they haven't already been loaded.
;;

(require "RXridge")

;;
;; Load data columnwise from ASCII format file into the variable coalfatl-dat.
;;

(def coalfatl-dat (read-data-columns "coalfatl.dat" 7))

;;
;; Save regressor/response coordinates in individual variable names.
;;

(def cutters   (select coalfatl-dat 0))             ; get single variables
(def tonperhr  (select coalfatl-dat 1))             ; out of read data
(def undrgrnd  (select coalfatl-dat 2))
(def mobiles   (select coalfatl-dat 3))
(def contins   (select coalfatl-dat 4))
(def totprohr  (select coalfatl-dat 5))
(def fatals    (select coalfatl-dat 6))

;;
;; Then construct a XLisp-Stat regression object...
;;

(def coalfatl-reg (regression-model
        (list cutters tonperhr undrgrnd mobiles contins totprohr) fatals
         :predictor-names '("CUTTERS" "TONPERHR" "UNDRGRND" "MOBILES"
                            "CONTINS" "TOTPROHR")
         :response-name "FATALS"
             )
)

;;
;; Inform user of the NAME of the model object ...so that he/she can send
;; his/her own messages to the object!!!
;;

(format t "(RXridge regression model is called 'coalfatl-reg') ~%")

;;
;; Create a MENU for the model.
;;

(send coalfatl-reg :RXridge-menu "FATALS")
(send coalfatl-reg :RXridge-compute-summary)

;;
;; Everything else can be done interactively with the "FATALS" MENU!!!
;;

