;; Data on 32 automobiles from Motor Trends magazine used by
;; Hocking(1976), "The Analysis and Selection of Variables in
;; Regression," Biometrics 32, 1-51.
;;
;; ...but using the model formulation from Henderson and Velleman(1981)
;; "Building Multiple Regression Models Interactively," Biometrics 37, 391-411.
;;
;;  CYLNDS = number of cylinders
;;  CUBINS = cubic inches of engine displacement
;;  OVRP   = horsepower * 100 / weight = measure of extent overpowered
;;  WEIGHT = total auto weight in pounds
;;  GPHM   = gallons per hundred miles
;;
;; Fetch softRX shrinkage routines if they haven't already been loaded.
;;

(require "RXridge")

;;
;; Load data columnwise from ASCII format file into the variable gphm-dat.
;;

(def gphm-dat (read-data-columns "gphm.dat" 6))

;;
;; Save regressor/response coordinates in individual variable names.
;;

(def cyl     (select gphm-dat 0))               ; get single variables
(def cub     (select gphm-dat 1))               ; out of read data
(def ovrp    (select gphm-dat 2))
(def wght    (select gphm-dat 3))
(def gphm    (select gphm-dat 4))

;;
;; Then construct a XLisp-Stat regression object...
;;

(def gphm-reg (regression-model (list cyl cub ovrp wght) gphm
                               :predictor-names '("CYL" "CUB" "OVRP" "WGHT" )
                               :response-name "GPHM"
             )
)

;;
;; Inform user of the NAME of the model object ...so that he/she can send
;; his/her own messages to the object!!!
;;

(format t "(RXridge regression model is called 'gphm-reg') ~%")

;;
;; Create a MENU for the model.
;;

(send gphm-reg :RXridge-menu "GPHM")
(send gphm-reg :RXridge-compute-summary)

;;
;; Everything else can be done interactively with the "GPHM" MENU!!!
;;

