;;  The "Portland Cement" data of Hald(1952), page 647
;;
;;     CA3 = Proportion of 3CaO.Al2O3 in the mixture.
;;     CS3 = Proportion of 3CaO.SiO2 in the mixture.
;;    CAF4 = Proportion of 4CaO.Al2O3.Fe2O3 in the mixture.
;;     CS2 = Proportion of 2CaO.SiO2  in the mixture.
;;    HEAT = Heat Evolved in Drying
;;
;;     Note: Each proportion appears to be rounded down to the
;;           nearest full percentage point; but X1+X2+X3+X4
;;           varies "only" from 95 to 99.
;;
;; Fetch softRX shrinkage routines if they haven't already been loaded.
;;

(require "RXridge")

;;
;; Load data columnwise from ASCII format file into the variable haldcemt-dat.
;;

(def haldcemt-dat (read-data-columns "haldcemt.dat" 5))

;;
;; Save regressor/response coordinates in individual variable names.
;;

(def ca3     (select haldcemt-dat 0))               ; get single variables
(def cs3     (select haldcemt-dat 1))               ; out of read data
(def caf4    (select haldcemt-dat 2))
(def cs2     (select haldcemt-dat 3))
(def heat    (select haldcemt-dat 4))

;;
;; Then construct a XLisp-Stat regression object...
;;

(def haldcemt-reg (regression-model (list ca3 cs3 caf4 cs2) heat
                     :predictor-names '("CA3" "CS3" "CAF4" "CS2" )
                     :response-name "HEAT"
                  )
)

;;
;; Inform user of the NAME of the model object ...so that he/she can send
;; his/her own messages to the object!!!
;;

(format t "(RXridge regression model is called 'haldcemt-reg') ~%")

;;
;; Create a MENU for the model.
;;

(send haldcemt-reg :RXridge-menu "HEAT")
(send haldcemt-reg :RXridge-compute-summary)

;;
;; Everything else can be done interactively with the "HEAT" MENU!!!
;;

