;; These are the "Modern" Longley Data (1947-1975): employment and
;; earnings data from the "Employment and Training Report of the
;; President 1976" compiled by Art Hoerl, University of Delaware.
;; Longley(1967), J. Amer. Statist. Assoc. 62, 819-841, used slightly
;; different numerical values and only the 16 years from 1947 to 1962.
;;
;; Fetch softRX shrinkage routines if they haven't already been loaded.
;;

(require "RXridge")

;;
;; Load data columnwise from ASCII format file into the variable longley-dat.
;;

(def longley2-dat (read-data-columns "longley2.dat" 7))

;;
;; Save regressor/response coordinates in individual variable names.
;;

(def gnpdef  (select longley-dat 0))               ; get single variables
(def unemp   (select longley-dat 1))               ; out of read data
(def afsize  (select longley-dat 2))
(def pop     (select longley-dat 3))
(def year    (select longley-dat 4))
(def emp     (select longley-dat 5))
(def gnp     (select longley-dat 6)) 

;;
;; Then construct a XLisp-Stat regression object...
;;

(def longley2-reg (regression-model (list gnpdef gnp unemp afsize pop year) emp
             :predictor-names '("GNPDEF" "GNP" "UNEMP" "AFSIZE" "POP" "YEAR" )
             :response-name "EMP"
      )
)

;;
;; Inform user of the NAME of the model object ...so that he/she can send
;; his/her own messages to the object!!!
;;

(format t "(RXridge regression model is called 'longley2-reg') ~%")

;;
;; Create a MENU for the model.
;;

(send longley2-reg :RXridge-menu "Longley2")
(send longley2-reg :RXridge-compute-summary)

;;
;; Everything else can be done interactively with the "Longley2" MENU!!!
;;
