;; Data from 17 US Naval Hospitals ...predictor variables are
;; "workload" variables (i.e. items that result in need for manpower.)
;;
;;      PLOAD = average daily patient load
;;      XRAYS = monthly X-ray exposures
;;      BDAYS = monthly occupied bed days
;;      ELPOP = eligible population in the area (thousands)
;;      STAYD = average patient stay in days
;;      MANHR = monthly man-hours
;;
;; Goal: Develop an empirical equation to estimate (predict) manpower
;; needs at Naval Hospitals.
;;
;; Procedures and Analysis for Staffing Standards Development:
;; Data/Regression Analysis Handbook (1979) San Diego, California:
;; Manpower and Material Analysis Center.
;;
;; Fetch softRX shrinkage routines if they haven't already been loaded.
;;

(require "RXridge")

;;
;; Load data columnwise from ASCII format file into the variable navlhosp-dat.
;;

(def navlhosp-dat (read-data-columns "navlhosp.dat" 6))

;;
;; Save regressor/response coordinates in individual variable names.
;;

(def pload   (select navlhosp-dat 0))               ; get single variables
(def xrays   (select navlhosp-dat 1))               ; out of read data
(def bdays   (select navlhosp-dat 2))
(def elpop   (select navlhosp-dat 3))
(def stayd   (select navlhosp-dat 4))
(def manhr   (select navlhosp-dat 5))

;;
;; Then construct a XLisp-Stat regression object...
;;

(def navlhosp-reg (regression-model (list pload xrays bdays elpop stayd) manhr
                   :predictor-names '("PLOAD" "XRAYS" "BDAYS" "ELPOP" "STAYD")
                   :response-name "MANHR"
                  )
)

;;
;; Inform user of the NAME of the model object ...so that he/she can send
;; his/her own messages to the object!!!
;;

(format t "(RXridge regression model is called 'navlhosp-reg') ~%")

;;
;; Create a MENU for the model.
;;

(send navlhosp-reg :RXridge-menu "MANHR")
(send navlhosp-reg :RXridge-compute-summary)

;;
;; Everything else can be done interactively with the "MANHR" MENU!!!
;;

